
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print "1..0 # SKIP these tests are for testing by the author\n";
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Alders
Alders'
bolded
Carwyn
Dagfinn
DOCTYPE
Forsyth
href
Ilmari
img
ioncache
Mannsåker
param
params
Raybec
schemas
src
whitelisted
whitelisting
XSS
Olaf
olaf
Arthur
Axel
fREW
Schmidt
frioux
David
Golden
dagolden
Fitz
Elliott
fitz
Graham
Knop
haarg
TerMarsch
graham
Karen
Etheridge
ether
Mark
Jubenville
mark
perlpong
calyx238
skaufman
sam
lib
HTML
Restrict
